@@ -1,10 +1,8 @@
 from dnastack.client import *
 from .runs import commands as runs_commands
 from .run import commands as run_commands
-from dnastack.cli.utils import *
-from dnastack.cli.auth import get_oauth_token
-
-from ..utils import get_auth_params
+from ..utils import *
+from ..auth import get_oauth_token
 
 
 @click.group()
@@ -16,23 +14,23 @@ def wes(ctx):
 @wes.command(name="info")
 @click.pass_context
 def get_service_info(ctx):
-    oauth_token = get_config(ctx, "oauth_token")
-    auth_params = get_auth_params(ctx, False)
+    oauth_token = get_oauth_token(ctx, wallet_url=get_config(ctx, "wes.wallet.url"))
+    auth_params = get_auth_params(ctx, service="wes", use_default=False)
 
     try:
         click.echo(
             json.dumps(
                 wes_client.get_service_info(
-                    get_config(ctx=ctx, var_name="wes-url", do_assert=True),
+                    get_config(ctx=ctx, var_path="wes.url"),
                     oauth_token,
                     auth_params,
                 ),
                 indent=4,
             )
         )
-    except:
+    except Exception as e:
         click.secho(
-            f"Error occurred while getting service info",
+            f"Unable to get WES service info: {e}",
             fg="red",
         )
         sys.exit(1)
