@@ -17,7 +17,7 @@ def query(
     download=False,
     format="json",
     raw=False,
-    oauth_token: Optional[str] = None,
+    oauth_token: Optional[dict] = None,
 ):
     dataconnect_client = get_dataconnect_client(dataconnect_url, oauth_token)
 
@@ -41,7 +41,7 @@ def query(
         return output
 
 
-def list_tables(dataconnect_url, oauth_token: Optional[str] = None):
+def list_tables(dataconnect_url, oauth_token: Optional[dict] = None):
     dataconnect_client = get_dataconnect_client(dataconnect_url, oauth_token)
 
     tables_iterator = dataconnect_client.get_table_list()
@@ -51,7 +51,7 @@ def list_tables(dataconnect_url, oauth_token: Optional[str] = None):
     )
 
 
-def get_table(dataconnect_url, table_name, oauth_token: Optional[str] = None):
+def get_table(dataconnect_url, table_name, oauth_token: Optional[dict] = None):
     dataconnect_client = get_dataconnect_client(dataconnect_url, oauth_token)
 
     table_info = dataconnect_client.get_table_info(table_name)
