@@ -1,10 +1,10 @@
 import os
 
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 
 # This is the public client wallet.publisher.dnastack.com used if the user does not set their own
 default_auth = {
-    "url": "https://wallet.publisher.dnastack.com",
+    "url": "https://wallet.publisher.dnastack.com/",
     "client": {
         "redirect_url": "https://wallet.publisher.dnastack.com/",
         "id": "publisher-cli",
