@@ -12,21 +12,22 @@ class TestCliWesCommand(unittest.TestCase):
     def setUp(self):
         self.runner = CliRunner()
         self.wes_url = TEST_WES_URI
-        self.runner.invoke(
-            dnastack_cli.dnastack,
-            [
-                "config",
-                "set",
-                "wes-url",
-                self.wes_url,
-            ],
+        self.wallet_url = TEST_AUTH_PARAMS["wes"]["url"]
+
+        clear_config()
+        set_cli_config(self.runner, "wes.url", self.wes_url)
+        set_auth_params_for_service(
+            self.runner, service="wes", auth_params=TEST_AUTH_PARAMS["wes"]
         )
-        set_auth_params(
+        set_cli_config(
             self.runner,
-            TEST_AUTH_PARAMS["wes"],
+            f"oauth|{self.wallet_url}|scope",
+            TEST_AUTH_SCOPES["wes"],
+            delimiter="|",
+        )
+        login_with_refresh_token_for_service(
+            self.runner, service="wes", refresh_token=TEST_WALLET_REFRESH_TOKEN["wes"]
         )
-        set_cli_config(self.runner, "oauth_token", ["scope", TEST_AUTH_SCOPES["wes"]])
-        login_with_refresh_token(self.runner, TEST_WALLET_REFRESH_TOKEN["wes"])
 
     def test_wes_info_with_auth(self):
         result = self.runner.invoke(dnastack_cli.dnastack, ["wes", "info"])
