@@ -1,6 +1,6 @@
 import os
 import unittest
-from dnastack import PublisherClient
+from dnastack import PublisherClient, ServiceType
 from .. import *
 
 
@@ -14,7 +14,20 @@ def assert_has_property(self, obj, attribute):
 
 class TestClientLibraryCollectionsCommand(unittest.TestCase):
     def setUp(self):
-        self.publisher_client = PublisherClient(collections_url=TEST_COLLECTIONS_URI)
+        self.publisher_client = PublisherClient(
+            email=TEST_WALLET_EMAIL,
+            personal_access_token=TEST_WALLET_PERSONAL_ACCESS_TOKEN_PUBLISHER,
+            collections_url=TEST_COLLECTIONS_URI,
+        )
+
+        self.publisher_client.auth.set_refresh_token_for_service(
+            service_type=ServiceType.COLLECTIONS,
+            token=TEST_WALLET_REFRESH_TOKEN["publisher"],
+        )
+        self.publisher_client.auth.oauth[TEST_AUTH_PARAMS["publisher"]["url"]][
+            "scope"
+        ] = TEST_AUTH_SCOPES["publisher"]
+        self.publisher_client.auth.login_for_service(service=ServiceType.COLLECTIONS)
 
     def test_collections_list(self):
         result_objects = self.publisher_client.collections.list()
