@@ -1,6 +1,6 @@
 import os
 import unittest
-from dnastack import PublisherClient
+from dnastack import PublisherClient, ServiceType
 from .. import *
 
 
@@ -14,7 +14,20 @@ def assert_has_property(self, obj, attribute):
 
 class TestClientLibraryDataConnectQueryCommand(unittest.TestCase):
     def setUp(self):
-        self.publisher_client = PublisherClient(dataconnect_url=TEST_DATA_CONNECT_URI)
+        self.publisher_client = PublisherClient(
+            email=TEST_WALLET_EMAIL,
+            personal_access_token=TEST_WALLET_PERSONAL_ACCESS_TOKEN_PUBLISHER,
+            dataconnect_url=TEST_DATA_CONNECT_URI,
+        )
+
+        self.publisher_client.auth.set_refresh_token_for_service(
+            service_type=ServiceType.DATACONNECT,
+            token=TEST_WALLET_REFRESH_TOKEN["publisher"],
+        )
+        self.publisher_client.auth.oauth[TEST_AUTH_PARAMS["publisher"]["url"]][
+            "scope"
+        ] = TEST_AUTH_SCOPES["publisher"]
+        self.publisher_client.auth.login_for_service(service=ServiceType.DATACONNECT)
 
     def test_variant_query(self):
         result = self.publisher_client.dataconnect.query(
