@@ -1,7 +1,7 @@
 import os
 import unittest
 import pathlib
-from dnastack import PublisherClient
+from dnastack import PublisherClient, ServiceType
 from .. import *
 import json
 
@@ -9,12 +9,22 @@ import json
 class TestCliWesCommand(unittest.TestCase):
     def setUp(self):
         self.publisher_client = PublisherClient(
-            wes_url=TEST_WES_URI, auth_params=TEST_AUTH_PARAMS["wes"]
+            email=TEST_WALLET_EMAIL,
+            personal_access_token=TEST_WALLET_PERSONAL_ACCESS_TOKEN_PUBLISHER,
+            wes_url=TEST_WES_URI,
+            auth_params=TEST_AUTH_PARAMS["wes"],
         )
+
         self.wes_url = TEST_WES_URI
-        self.publisher_client.auth.oauth_token["scope"] = TEST_AUTH_SCOPES["wes"]
-        self.publisher_client.auth.set_refresh_token(TEST_WALLET_REFRESH_TOKEN["wes"])
-        self.publisher_client.auth.refresh_token()
+        self.publisher_client.auth.set_refresh_token_for_service(
+            service_type=ServiceType.WES, token=TEST_WALLET_REFRESH_TOKEN["wes"]
+        )
+        self.publisher_client.auth.oauth[TEST_AUTH_PARAMS["wes"]["url"]][
+            "scope"
+        ] = TEST_AUTH_SCOPES["wes"]
+        self.publisher_client.auth.refresh_token_for_service(
+            service_type=ServiceType.WES
+        )
 
     def test_wes_info_with_auth(self):
         result = self.publisher_client.wes.info()
